<?php
/************************************************************************
 * Mailer v0.2.1-FINAL                                Start: 06/24/2012 *
 * ===================                          Last change: 06/24/2012 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : ajax_admin.php                                   *
 * -------------------------------------------------------------------- *
 * Short description : AJAX library for admin menu                      *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : AJAX-Bibliothek fuer Adminmenu                   *
 * -------------------------------------------------------------------- *
 * $Revision::                                                        $ *
 * $Date::                                                            $ *
 * $Tag:: 0.2.1-FINAL                                                 $ *
 * $Author::                                                          $ *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * Copyright (c) 2009 - 2012 by Mailer Developer Team                   *
 * For more information visit: http://mxchange.org                      *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if ((!defined('__SECURITY')) || (!isAdmin())) {
	die();
} // END - if

// "Generates" admin content by loading a message template
function generateAdminContent () {
	// Return it
	return displayMessage('{--ADMIN_AJAX_MENU_IS_LOADING--}', true);
}

// Processes AJAX requests for admin menu
function doAjaxProcessAdmin () {
	// 'do' must always be set and isAdmin must be true
	if (!isAdmin()) {
		// This shall not happen
		reportBug(__FUNCTION__, __LINE__, 'This AJAX request handler was called outside the admin menu.');
	} elseif (!isPostRequestElementSet('do')) {
		// This shall not happen
		reportBug(__FUNCTION__, __LINE__, 'The JavaScript did not send "do" which is fatal.');
	} // END - if

	// Again we do a call-back, so generate a function name depending on 'do'
	$callbackName = 'doAjaxAdmin' . capitalizeUnderscoreString(postRequestElement('do'));

	// Is the call-back function there?
	if (!function_exists($callbackName)) {
		// This shall not happen
		reportBug(__FUNCTION__, __LINE__, 'AJAX call-back ' . $callbackName . ' does not exist.');
	} // END - if

	// Call the function
	call_user_func($callbackName);

	// Send AJAX content
	sendAjaxContent();
}

// Processes admin AJAX calls for content-requests
function doAjaxAdminRequestContent () {
	// 'tab' must be there
	if (!isPostRequestElementSet('tab')) {
		// This shall not happen
		reportBug(__FUNCTION__, __LINE__, 'The JavaScript did not send "tab" which is fatal.');
	} // END - if

	// Construct call-back name for value-preset
	$callbackName = 'doAjaxPrepareAdmin' . capitalizeUnderscoreString(postRequestElement('tab'));

	// Is the function there?
	if (function_exists($callbackName)) {
		// Call it for setting values in session
		call_user_func($callbackName);
	} else {
		// Log missing functions
		logDebugMessage(__FUNCTION__, __LINE__, 'Call-back function ' . $callbackName . ' does not exist.');
	}

	// Is the HTTP status still the same? (204 No Content)
	if (getHttpStatus() == '204 No Content') {
		// We use the current access level 'install' as prefix and construct a template name
		setAjaxReplyContent(loadTemplate('admin_area_' . trim(postRequestElement('tab')), true));

		// Has the template been loaded?
		if (isset($GLOBALS['tpl_content']['admin_page_' . trim(postRequestElement('tab'))])) {
			// All okay if we reach this point
			setHttpStatus('200 OK');
		} else {
			// Set 404 error
			setHttpStatus('404 NOT FOUND');
		}
	} // END - if
}
// [EOF]
?>
