<?php
/************************************************************************
 * Mailer v0.2.1-FINAL                                Start: 10/08/2005 *
 * ===================                          Last change: 01/01/2006 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : gen_sql_patches.php                              *
 * -------------------------------------------------------------------- *
 * Short description : Patch password system after upgrading            *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Patcht das Passwort-System nach DB-Update        *
 * -------------------------------------------------------------------- *
 * $Revision::                                                        $ *
 * $Date::                                                            $ *
 * $Tag:: 0.2.1-FINAL                                                 $ *
 * $Author::                                                          $ *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * Copyright (c) 2009 - 2012 by Mailer Developer Team                   *
 * For more information visit: http://mxchange.org                      *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if (!defined('__SECURITY')) {
	die();
} // END - if

// Check if there is no scrambling string
if (getPassScramble() == '') {
	// Generate 40 chars long scramble string
	$scrambleString = genScrambleString(40);

	// ... and store it there for future usage
	updateConfiguration('pass_scramble', $scrambleString);

	// Remove dummy string
	unset($scrambleString);
} // END - if

// Check if there is no master salt string
if (getMasterSalt() == '') {
	// Generate the master salt which is the first chars minus 40 chars of this random hash
	// We do an extra scrambling here...
	$masterSalt = scrambleString(sha1(generatePassword(mt_rand(128, 256))));

	// ... and store it there for future usage
	updateConfiguration('master_salt', $masterSalt);

	// Remove dummy string
	unset($masterSalt);
} // END - if

if (getFileHash() == '') {
	// Create filename from hashed random string
	$fileHash = sha1(generatePassword(mt_rand(128, 256)));
	$FQFN = sprintf("%s%s.%s.cache",
		getPath(),
		getCachePath(),
		$fileHash
	);

	// Generate secret key from a randomized string
	$secretKey = sha1(generateHash(mt_rand(128, 256)));

	// File hash was never created
	writeToFile($FQFN, $secretKey);

	// Is the file there?
	if (isFileReadable($FQFN)) {
		// Also update configuration
		setConfigEntry('secret_key', $secretKey);
		updateConfiguration('file_hash', $fileHash);

		// Remove variables
		unset($secretKey);
		unset($fileHash);
	} // END - if
} // END - if

// @TODO Rewrite this to a filter
if ((isExtensionInstalledAndNewer('cache', '0.1.2')) && (isCacheInstanceValid())) {
	// Destroy some cache files
	if ($GLOBALS['cache_instance']->loadCacheFile('config'))    $GLOBALS['cache_instance']->removeCacheFile();
	if ($GLOBALS['cache_instance']->loadCacheFile('extension')) $GLOBALS['cache_instance']->removeCacheFile();
	if ($GLOBALS['cache_instance']->loadCacheFile('modules'))   $GLOBALS['cache_instance']->removeCacheFile();
} // END - if

// [EOF]
?>
