<?php
/************************************************************************
 * Mailer v0.2.1-FINAL                                Start: 11/14/2003 *
 * ===================                          Last change: 11/13/2004 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : mailid_top.php                                   *
 * -------------------------------------------------------------------- *
 * Short description : Confirmation file for emails                     *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Bestaetigung von Mails                           *
 * -------------------------------------------------------------------- *
 * $Revision::                                                        $ *
 * $Date::                                                            $ *
 * $Tag:: 0.2.1-FINAL                                                 $ *
 * $Author::                                                          $ *
 * -------------------------------------------------------------------- *
 * @TODO Merge this script with mailid.php                              *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * Copyright (c) 2009 - 2012 by Mailer Developer Team                   *
 * For more information visit: http://mxchange.org                      *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Load security stuff here
require('inc/libs/security_functions.php');

// Init start time
$GLOBALS['__start_time'] = microtime(true);

// Tell everyone we are in this module
$GLOBALS['__module']      = 'mailid';
$GLOBALS['__output_mode'] = '0';

// Disable copyright footer which would be to large for the upper frame
$GLOBALS['__copyright_enabled'] = 'N';

// Load the required file(s)
require('inc/config-global.php');

// Set content type and HTTP status
setContentType('text/html');
setHttpStatus('404 Not Found');

// Is the extension mailid active?
redirectOnUninstalledExtension('mailid');

// Is the extension other active?
redirectOnUninstalledExtension('other');

// Init variables
$userId = '0';
$bonusId = '0';
$mailId = '0';
$code = '0';
$do = '';

// Secure all data
if (isGetRequestElementSet('userid'))  $userId  = bigintval(getRequestElement('userid'));
if (isGetRequestElementSet('mailid'))  $mailId  = bigintval(getRequestElement('mailid'));
if (isGetRequestElementSet('bonusid')) $bonusId = bigintval(getRequestElement('bonusid'));
if (isGetRequestElementSet('code'))    $code    = bigintval(getRequestElement('code'));
if (isGetRequestElementSet('do'))      $do      = getRequestElement('do');

// 01             2       21    12           2    2            21    1                      2210
if ((isValidUserId($userId)) && (($mailId > 0) || ($bonusId > 0)) && (!ifFatalErrorsDetected())) {
	// No image?
	if ($do != 'img') {
		// ... then output header
		loadIncludeOnce('inc/header.php');
	} // END - fi

	// Maybe he wants to confirm an email?
	if ($mailId > 0) {
		$result_main = SQL_QUERY_ESC("SELECT `id`,`link_type` FROM `{?_MYSQL_PREFIX?}_user_links` WHERE `stats_id`=%s AND `userid`=%s LIMIT 1",
			array($mailId, $userId), __FILE__, __LINE__);
		$type = 'mailid';
		$urlId = $mailId;
	} elseif ($bonusId > 0) {
		$result_main = SQL_QUERY_ESC("SELECT `id`,`link_type` FROM `{?_MYSQL_PREFIX?}_user_links` WHERE `bonus_id`=%s AND `userid`=%s LIMIT 1",
			array($bonusId, $userId), __FILE__, __LINE__);
		$type = 'bonusid';
		$urlId = $bonusId;
	}

	if (SQL_NUMROWS($result_main) == 1) {
		// Is the stats id valid?
		list($lid, $ltype) = SQL_FETCHROW($result_main);

		// Init result here with invalid to avoid possible missing variable
		$result_mailid = false;

		// @TODO Rewrite this to a filter
		switch ($ltype) {
			case 'NORMAL':
				$result_mailid = SQL_QUERY_ESC("SELECT `pool_id`,`userid`,`id` FROM `{?_MYSQL_PREFIX?}_user_stats` WHERE `id`=%s LIMIT 1",
					array($mailId), __FILE__, __LINE__);
				break;

			case 'BONUS':
				$result_mailid = SQL_QUERY_ESC("SELECT `id`,`id`,`is_notify` FROM `{?_MYSQL_PREFIX?}_bonus` WHERE `id`=%s LIMIT 1",
					array($bonusId), __FILE__, __LINE__);
				break;

			default: // Unknown type
				reportBug(__FILE__, __LINE__, 'Unknown mail type ' . $ltype . ' detected.');
				break;
		}

		// Entry found?
		if (SQL_NUMROWS($result_mailid) == 1) {
			// Load data
			list($pool, $sender, $notify) = SQL_FETCHROW($result_mailid);

			// Correct notification switch in non-bonus mails
			if (!in_array($notify, array('Y', 'N'))) {
				$notify = 'N';
			} // END - if

			// Set sender to 0 when we have a bonus mail
			if ($ltype == 'BONUS') {
				$sender = '0';
			} // END - if

			// Is the user id valid?
			if (fetchUserData($userId) === true) {
				// Is the user status CONFIRMED?
				if (getUserData('status') == 'CONFIRMED') {
					// User has confirmed his account so we can procede...
					// @TODO Rewrite this to a filter
					switch ($ltype) {
						case 'NORMAL':
							$result = SQL_QUERY_ESC("SELECT `payment_id` FROM `{?_MYSQL_PREFIX?}_user_stats` WHERE `pool_id`=%s LIMIT 1",
								array(bigintval($pool)), __FILE__, __LINE__);

							// Entry found?
							if (SQL_NUMROWS($result) == 1) {
								list($pay) = SQL_FETCHROW($result);
								$time      = getPaymentPoints($pay, 'time');
								$payment   = getPaymentPoints($pay, 'payment');
								$isValid   = true;
							} // END - if

							// Free memory...
							SQL_FREERESULT($result);
							break;

						case 'BONUS':
							$result = SQL_QUERY_ESC("SELECT `time`,`points` FROM `{?_MYSQL_PREFIX?}_bonus` WHERE `id`=%s LIMIT 1",
								array(bigintval($pool)), __FILE__, __LINE__);

							// Entry found?
							if (SQL_NUMROWS($result) == 1) {
								list($time, $payment) = SQL_FETCHROW($result);
								$isValid = true;
							} // END - if

							// Free memory...
							SQL_FREERESULT($result);
							break;

						default: // Unknown type
							reportBug(__FILE__, __LINE__, 'Unknown mail type ' . $ltype . ' detected.');
							break;
					} // END - switch

					// Is this entry valid?
					if ($isValid === true) {
						if (($time == '0') && ($payment > 0)) $time = 1;
						if (($time > 0) && ($payment > 0)) {
							$realCode = '0';
							if (!empty($code)) {
								// Generate code (the user sees in the CAPTCHA)
								$realCode = generateRandomCode(getCodeLength(), $code, $userId, $urlId);
							} // END - if

							// @TODO Rewrite this to a filter
							switch ($do) {
								case 'add':
									// Init stats data
									$stats_data = '0';

									// Count clicks
									// @TODO Rewrite this to a filter
									switch ($ltype) {
										case 'NORMAL':
											SQL_QUERY_ESC("UPDATE `{?_MYSQL_PREFIX?}_user_stats` SET `clicks`=`clicks`+1 WHERE `id`=%s LIMIT 1",
												array($mailId), __FILE__, __LINE__);

											// Update mediadata as well
											if (isExtensionInstalledAndNewer('mediadata', '0.0.4')) {
												// Update database
												updateMediadataEntry(array('total_clicks', 'normal_clicks'), 'add', 1);
											} // END - if
											$stats_data = $mailId;
											break;

										case 'BONUS':
											SQL_QUERY_ESC("UPDATE `{?_MYSQL_PREFIX?}_bonus` SET `clicks`=`clicks`+1 WHERE `id`=%s LIMIT 1",
												array($bonusId), __FILE__, __LINE__);

											// Update mediadata as well
											if (isExtensionInstalledAndNewer('mediadata', '0.0.4')) {
												// Update database
												updateMediadataEntry(array('total_clicks', 'bonus_clicks'), 'add', 1);
											} // END - if
											$stats_data = $bonusId;
											break;

										default: // Unknown type
											reportBug(__FILE__, __LINE__, 'Unknown mail type ' . $ltype . ' detected.');
											break;
									} // END - switch

									// Export data into constants for the template
									$content['banner'] = loadTemplate('mailid_banner', true);

									// Only when user extension = v0.1.2: Update mails-confirmed counter
									// @TODO Rewrite these blocks to filter
									if (isExtensionInstalledAndNewer('user', '0.1.2')) {
										// Update counter
										SQL_QUERY_ESC("UPDATE `{?_MYSQL_PREFIX?}_user_data` SET `mails_confirmed`=`mails_confirmed`+1 WHERE `userid`=%s LIMIT 1",
											array($userId), __FILE__, __LINE__);

										// Update random confirmed as well?
										if ((isExtensionInstalledAndNewer('user', '0.3.4')) && (isRandomReferralIdEnabled())) {
											// Update second counter
											SQL_QUERY_ESC("UPDATE `{?_MYSQL_PREFIX?}_user_data` SET `rand_confirmed`=`rand_confirmed` + 1 WHERE `userid`=%s LIMIT 1",
												array($userId), __FILE__, __LINE__);
										} // END - if
									} // END - if

									// Insert stats record
									insertUserStatsRecord($userId, $type, $stats_data);

									// Right code entered?
									if (bigintval(postRequestElement('gfx_check')) == $realCode) {
										// Set HTTP status to okay
										setHttpStatus('200 OK');

										// Add points over referral system is the default
										$template = 'mailid_points_done';

										// Right code entered add points and remove entry
										if (ifUserPointsLocked($userId)) {
											// Don't add points over the referral system
											$template = 'mailid_points_locked';
										} // END - if

										// Count down ref_payout value
										SQL_QUERY_ESC("UPDATE `{?_MYSQL_PREFIX?}_user_data` SET `ref_payout`=`ref_payout`-1 WHERE `userid`=%s AND `ref_payout` > 0 LIMIT 1",
											array($userId), __FILE__, __LINE__);

										// Add points
										initReferralSystem();
										addPointsThroughReferralSystem('mailid_okay', $userId, $payment);

										// Shall I add bonus points for "turbo clickers" ?
										if (isExtensionInstalledAndNewer('bonus', '0.2.2')) {
											// Is an active-rallye running and this is not a notification mail?
											if ((isBonusRallyeActive()) && ($notify != 'Y')) {
												// Shall I exclude the webmaster's own userid from the active-rallye?
												if ((((getBonusUserid() == $userId) && (getConfig('bonus_include_own') == 'Y')) || (getBonusUserid() != $userId)) && (getDefRefid() != $userId)) {
													// Add points and remember ranking are done in this function....
													addTurboBonus($urlId, $userId, $type);

													// Set template to mailid_points_done2 which contains a link to the ranking list
													$template = 'mailid_points_done2';

													// Different template if user has some mails to confirm
													if (ifUserPointsLocked($userId)) {
														$template = 'mailid_points_locked2';
													} // END - if

													// Assign more data for the template
													$content['userid']  = $userId;
													$content['type']    = $type;
													$content['data']    = $urlId;
												} // END - if
											} // END - if
										} // END - if

										// Load total points
										$content['total_points']  = getTotalPoints($userId);

										// Add payment points
										$content['points'] = $payment;

										// Load template
										loadTemplate($template, false, $content);
									} elseif (isValidUserId($sender)) {
										// Wrong image code! So add points to sender's account
										initReferralSystem();
										addPointsThroughReferralSystem('mailid_payback', $sender, $payment);

										// Add payment points
										$content['points'] = $payment;

										// Load template
										loadTemplate('mailid_points_failed', false, $content);
									} else {
										// Add payment points (again)
										$content['points'] = $payment;

										// Load template
										loadTemplate('mailid_points_failed2', false, $content);
									}

									// Remove link from table
									SQL_QUERY_ESC("DELETE LOW_PRIORITY FROM `{?_MYSQL_PREFIX?}_user_links` WHERE `id`=%s LIMIT 1",
										array(bigintval($lid)), __FILE__, __LINE__);
									break;

								case 'img':
									generateImageOrCode($realCode);
									break;

								case 'confirm':
									if ($code > 0) {
										// Export data into constants for the template
										$content['code']   = $code;
										$content['userid'] = $userId;
										$content['type']   = $type;
										$content['data']   = $urlId;
										$content['banner'] = loadTemplate('mailid_banner', true);
										if (getCodeLength() > 0) {
											// Generate Code
											$content['image'] = generateCaptchaCode($code, $type, $urlId, $userId);
											$templ = 'mailid_enter_code';
										} else {
											// Disabled code
											$content['gfx'] = $realCode;
											$templ = 'mailid_confirm_buttom';
										}

										// Load template
										loadTemplate($templ, false, $content);
									} else {
										// Cannot confirm!
										reportBug(__FILE__, __LINE__, 'No code given.');
									}
									break;

								case '':
									// Ok, all data is valid and loaded. Finally let's output the timer... :-)
									// Export data into constants for the template
									$content['time']   = $time;
									$content['tim2']   = strlen($time);
									$content['userid'] = $userId;
									$content['type']   = $type;
									$content['data']   = $urlId;
									$content['rand']   = getRandomTan();
									$content['banner'] = loadTemplate('mailid_banner', true);

									// Load template
									loadTemplate('mailid_timer', false, $content);
									break;

								default: // Unknown mode
									reportBug(__FILE__, __LINE__, 'Unknown mode ' . $do . ' detected.');
									break;
							} // END - switch
						} else {
							loadTemplate('admin_settings_unsaved', false, '{--MAIL_ALREADY_CONFIRMED--} (6)');
							$do = 'failed';
						}
					} else {
						loadTemplate('admin_settings_unsaved', false, '{--MAIL_ALREADY_CONFIRMED--} (5)');
						$do = 'failed';
					}
				} else {
					loadTemplate('admin_settings_unsaved', false, '{--MAIL_ALREADY_CONFIRMED--} (4)');
					$do = 'failed';
				}
			} else {
				loadTemplate('admin_settings_unsaved', false, '{--MAIL_ALREADY_CONFIRMED--} (3)');
				$do = 'failed';
			}
		} else {
			loadTemplate('admin_settings_unsaved', false, '{--MAIL_ALREADY_CONFIRMED--} (2)');
			$do = 'failed';
		}

		// Free result
		SQL_FREERESULT($result_mailid);
	} else {
		loadTemplate('admin_settings_unsaved', false, '{--MAIL_ALREADY_CONFIRMED--} (1)');
		$do = 'failed';
	}

	// Free result
	SQL_FREERESULT($result_main);

	// Insert footer if no image
	if ($do != 'img') {
		// Write footer
		loadIncludeOnce('inc/footer.php');
	} // END - if
}

// Really all done here... ;-)
doShutdown();

// [EOF]
?>
